Learn R Programming

gggenomes (version 1.1.3)

read_blast: Read BLAST tab-separated output

Description

Read BLAST tab-separated output

Usage

read_blast(
  file,
  col_names = def_names("blast"),
  col_types = def_types("blast"),
  comment = "#",
  swap_query = FALSE,
  ...
)

Value

a tibble with the BLAST output

Arguments

file

Either a path to a file, a connection, or literal data (either a single string or a raw vector). file can also be a character vector containing multiple filepaths or a list containing multiple connections.

Files ending in .gz, .bz2, .xz, or .zip will be automatically decompressed. Files starting with http://, https://, ftp://, or ftps:// will be automatically downloaded. Remote compressed files (.gz, .bz2, .xz, .zip) will be automatically downloaded and decompressed.

Literal data is most useful for examples and tests. To be recognised as literal data, wrap the input with I().

col_names

column names to use. Defaults to def_names("blast") compatible with blast tabular output (--outfmt 6/7 in blast++ and -m8 in blast-legacy). def_names() can easily be combined with extra columns: col_names = c(def_names("blast"), "more", "things").

col_types

column types to use. Defaults to def_types("gff3") (see def_types).

comment

character

swap_query

if TRUE swap query and subject columns using swap_query() on import.

...

additional parameters, passed to read_tsv