Read BLAST tab-separated output
read_blast(
file,
col_names = def_names("blast"),
col_types = def_types("blast"),
comment = "#",
swap_query = FALSE,
...
)a tibble with the BLAST output
Either a path to a file, a connection, or literal data (either a
single string or a raw vector). file can also be a character vector
containing multiple filepaths or a list containing multiple connections.
Files ending in .gz, .bz2, .xz, or .zip will be automatically
decompressed. Files starting with http://, https://, ftp://, or
ftps:// will be automatically downloaded. Remote compressed files
(.gz, .bz2, .xz, .zip) will be automatically downloaded and
decompressed.
Literal data is most useful for examples and tests. To be recognised as
literal data, wrap the input with I().
column names to use. Defaults to def_names("blast")
compatible with blast tabular output (--outfmt 6/7 in blast++ and -m8
in blast-legacy). def_names() can easily be combined with extra
columns: col_names = c(def_names("blast"), "more", "things").
column types to use. Defaults to def_types("gff3") (see def_types).
character
if TRUE swap query and subject columns using swap_query()
on import.
additional parameters, passed to read_tsv